@@ -1,7 +1,7 @@
 import { KnipConfig } from "knip";
 
 export default {
-    entry: ["src/electron-main.ts", "src/preload.ts", "electron-builder.ts", ".eslintrc-*.js", "scripts/**", "hak/**"],
+    entry: ["src/preload.cts", "electron-builder.ts", "scripts/**", "hak/**"],
     project: ["**/*.{js,ts}"],
     ignoreDependencies: [
         // Brought in via hak scripts
@@ -10,6 +10,8 @@ export default {
         "@action-validator/*",
         // Used for git pre-commit hooks
         "husky",
+        // Required for `patch-package`
+        "postinstall-postinstall",
     ],
     ignoreBinaries: ["jq", "scripts/in-docker.sh"],
 } satisfies KnipConfig;
