@@ -89,6 +89,8 @@ interface StoreData {
     safeStorageBackendOverride?: boolean;
     /** whether to perform a migration of the safeStorage data */
     safeStorageBackendMigrate?: boolean;
+    /** whether to open the app at login minimised, only valid when app.openAtLogin is true */
+    openAtLoginMinimised: boolean;
 }
 
 /**
@@ -232,6 +234,10 @@ class Store extends ElectronStore<StoreData> {
                 safeStorageBackendMigrate: {
                     type: "boolean",
                 },
+                openAtLoginMinimised: {
+                    type: "boolean",
+                    default: true,
+                },
             },
         });
     }
